﻿clc
//Reactor batch
InitialValue=1
Start=0
Finish=10
Nsteps=100
//
function [f] = TestFunction(x,t)
f = -x; //aquí la constante de tiempo es la unidad
endfunction
//
function [x,t] = Euler(TestFunction,InitialValue,Start,Finish,Nsteps)
// Resuelve el problema de valores iniciales dx/dt = f(x)
// Utiliza el método de Euler
//
// ENTRADAS
// ------
// InitialValue = condición inicial
// Start        = tiempo inicial
// Finish       = tiempo finsl
// Nsteps       = número de pasos o etapas
//
// SALIDAS
// -------
// x            = vector que contiene la solución para cada instante de tiempo
// t            = vector que contiene los tiempos correspondientes a cada elemento de x
//
// Descripción
// -----------
// Utiliza el método explícito de Euler para reolver una ODE de la forma dx/dt=f(x,t). 
// La function f(x,t) debe ser suministrada por el usuario y de la forma:
// function [dx/dt] = f(t,x)
// Sus argumentos de entrada son el tiempo t y la solución a ese tiempo, x(t). Esto es, retorna
// la variación temporal de la variable dependiente x.
//
x(1) = InitialValue;
t(1) = Start;
//
//calcula el paso temporal
dt = (Finish-Start)/Nsteps;
//
for i = 1:Nsteps
    //calcula el gradiente usando la solución corriente (tiempo = t)
    F = feval(x(i),t(i),TestFunction);
    //calcula el nuevo valor de x y de t
    t(i+1) = dt + t(i);
    x(i+1) = F*dt + x(i);    
end
//
t = t';
x = x';
endfunction
//
[x,t] = Euler(TestFunction,InitialValue,Start,Finish,Nsteps);
y=exp(-t);
matrix=[y' x'];
plot2d(t,[matrix(:,1) matrix(:,2)],[1:2],leg='Solución exacta@Método de Euler');
title('Método de Euler Explícito');
xlabel('t');
ylabel('x');
